@@ -10,12 +10,8 @@ describe 'cinder::backend::netapp' do
       :netapp_login                 => 'netapp',
       :netapp_password              => 'password',
       :netapp_server_hostname       => '127.0.0.2',
-      :netapp_vfiler                => 'netapp_vfiler',
       :netapp_vserver               => 'netapp_vserver',
-      :netapp_partner_backend_name  => 'fc2',
       :netapp_copyoffload_tool_path => '/tmp/na_copyoffload_64',
-      :netapp_controller_ips        => '10.0.0.2,10.0.0.3',
-      :netapp_sa_password           => 'password',
     }
   end
 
@@ -32,7 +28,6 @@ describe 'cinder::backend::netapp' do
       :thres_avl_size_perc_stop    => '60',
       :nfs_shares_config           => '/etc/cinder/shares.conf',
       :nfs_mount_options           => '<SERVICE DEFAULT>',
-      :netapp_webservice_path      => '/devmgr/v2',
       :nas_secure_file_operations  => '<SERVICE DEFAULT>',
       :nas_secure_file_permissions => '<SERVICE DEFAULT>',
     }
@@ -43,17 +38,16 @@ describe 'cinder::backend::netapp' do
       default_params.merge(params)
     end
 
-    it { should contain_cinder_config('netapp/volume_driver').with_value('cinder.volume.drivers.netapp.common.NetAppDriver') }
+    it { is_expected.to contain_cinder_config('netapp/volume_driver').with_value('cinder.volume.drivers.netapp.common.NetAppDriver') }
 
     it {
       params_hash.each_pair do |config,value|
-        should contain_cinder_config("netapp/#{config}").with_value( value )
+        is_expected.to contain_cinder_config("netapp/#{config}").with_value( value )
       end
     }
 
     it {
-      should contain_cinder_config('netapp/netapp_password').with_secret( true )
-      should contain_cinder_config('netapp/netapp_sa_password').with_secret( true )
+      is_expected.to contain_cinder_config('netapp/netapp_password').with_secret( true )
     }
   end
 
@@ -70,20 +64,12 @@ describe 'cinder::backend::netapp' do
       it_behaves_like 'netapp volume driver'
     end
 
-    context 'with netapp_storage_family eseries' do
-      before do
-        params.merge!( :netapp_storage_family => 'eseries' )
-      end
-
-      it { should contain_cinder_config('netapp/use_multipath_for_image_xfer').with_value('true') }
-    end
-
     context 'with nfs_mount_options' do
       before do
         params.merge!( :nfs_mount_options => 'rw,proto=tcp,sec=sys' )
       end
 
-      it { should contain_cinder_config('netapp/nfs_mount_options').with_value('rw,proto=tcp,sec=sys') }
+      it { is_expected.to contain_cinder_config('netapp/nfs_mount_options').with_value('rw,proto=tcp,sec=sys') }
     end
 
     context 'netapp backend with cinder type' do
@@ -91,7 +77,7 @@ describe 'cinder::backend::netapp' do
         params.merge!( :manage_volume_type => true )
       end
 
-      it { should contain_cinder_type('netapp').with(
+      it { is_expected.to contain_cinder_type('netapp').with(
         :ensure     => 'present',
         :properties => ['volume_backend_name=netapp']
       )}
@@ -102,7 +88,7 @@ describe 'cinder::backend::netapp' do
         params.merge!( :extra_options => {'netapp/param1' => { 'value' => 'value1' }} )
       end
 
-      it { should contain_cinder_config('netapp/param1').with_value('value1') }
+      it { is_expected.to contain_cinder_config('netapp/param1').with_value('value1') }
     end
 
     context 'with NFS shares provided' do
@@ -111,7 +97,7 @@ describe 'cinder::backend::netapp' do
                        :nfs_shares_config => '/etc/cinder/shares.conf' )
       end
 
-      it { should contain_file('/etc/cinder/shares.conf').with(
+      it { is_expected.to contain_file('/etc/cinder/shares.conf').with(
         :content => "10.0.0.1:/test1\n10.0.0.2:/test2",
       )}
     end
@@ -124,7 +110,7 @@ describe 'cinder::backend::netapp' do
         })
       end
 
-      it { should raise_error(Puppet::Error) }
+      it { is_expected.to raise_error(Puppet::Error) }
     end
 
     context 'with name search pattern' do
@@ -132,7 +118,7 @@ describe 'cinder::backend::netapp' do
         params.merge!( :netapp_pool_name_search_pattern => '(something)' )
       end
 
-      it { should contain_cinder_config('netapp/netapp_pool_name_search_pattern').with_value('(something)') }
+      it { is_expected.to contain_cinder_config('netapp/netapp_pool_name_search_pattern').with_value('(something)') }
     end
   end
 
